# -*- coding:utf-8 -*-
# author：huawei


BACKEND_SERVICE = "127.0.0.1:11800"

SERVICE_ID = 0

SERVICE_NAME = "python-test"

SERVICE_INSTANCE_ID = 0

IGNORE_SUFFIX = ["ico", "css", "jpg", "js"]

OPERATION_NAME_THRESHOLD = 500

AGENT_VERSION = ""

REGISTER_INTERVAL = 10

SKYWALKING_HERADER_V2 = "sw6"
