# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from python2sky.proto.common import common_pb2 as common_dot_common__pb2
from python2sky.proto.register import InstancePing_pb2 as register_dot_InstancePing__pb2


class ServiceInstancePingStub(object):
    """Missing associated documentation comment in .proto file"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.doPing = channel.unary_unary(
                '/ServiceInstancePing/doPing',
                request_serializer=register_dot_InstancePing__pb2.ServiceInstancePingPkg.SerializeToString,
                response_deserializer=common_dot_common__pb2.Commands.FromString,
                )


class ServiceInstancePingServicer(object):
    """Missing associated documentation comment in .proto file"""

    def doPing(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceInstancePingServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'doPing': grpc.unary_unary_rpc_method_handler(
                    servicer.doPing,
                    request_deserializer=register_dot_InstancePing__pb2.ServiceInstancePingPkg.FromString,
                    response_serializer=common_dot_common__pb2.Commands.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ServiceInstancePing', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServiceInstancePing(object):
    """Missing associated documentation comment in .proto file"""

    @staticmethod
    def doPing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServiceInstancePing/doPing',
            register_dot_InstancePing__pb2.ServiceInstancePingPkg.SerializeToString,
            common_dot_common__pb2.Commands.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)
