# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/trace-common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common/trace-common.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n0org.apache.skywalking.apm.network.language.agentP\001\252\002\032SkyWalking.NetworkProtocol',
  serialized_pb=b'\n\x19\x63ommon/trace-common.proto\"E\n\x0fUpstreamSegment\x12!\n\x0eglobalTraceIds\x18\x01 \x03(\x0b\x32\t.UniqueId\x12\x0f\n\x07segment\x18\x02 \x01(\x0c\"\x1b\n\x08UniqueId\x12\x0f\n\x07idParts\x18\x01 \x03(\x03**\n\x08SpanType\x12\t\n\x05\x45ntry\x10\x00\x12\x08\n\x04\x45xit\x10\x01\x12\t\n\x05Local\x10\x02*,\n\x07RefType\x12\x10\n\x0c\x43rossProcess\x10\x00\x12\x0f\n\x0b\x43rossThread\x10\x01*U\n\tSpanLayer\x12\x0b\n\x07Unknown\x10\x00\x12\x0c\n\x08\x44\x61tabase\x10\x01\x12\x10\n\x0cRPCFramework\x10\x02\x12\x08\n\x04Http\x10\x03\x12\x06\n\x02MQ\x10\x04\x12\t\n\x05\x43\x61\x63he\x10\x05\x42Q\n0org.apache.skywalking.apm.network.language.agentP\x01\xaa\x02\x1aSkyWalking.NetworkProtocolb\x06proto3'
)

_SPANTYPE = _descriptor.EnumDescriptor(
  name='SpanType',
  full_name='SpanType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Entry', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Exit', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Local', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=129,
  serialized_end=171,
)
_sym_db.RegisterEnumDescriptor(_SPANTYPE)

SpanType = enum_type_wrapper.EnumTypeWrapper(_SPANTYPE)
_REFTYPE = _descriptor.EnumDescriptor(
  name='RefType',
  full_name='RefType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CrossProcess', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CrossThread', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=173,
  serialized_end=217,
)
_sym_db.RegisterEnumDescriptor(_REFTYPE)

RefType = enum_type_wrapper.EnumTypeWrapper(_REFTYPE)
_SPANLAYER = _descriptor.EnumDescriptor(
  name='SpanLayer',
  full_name='SpanLayer',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Database', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPCFramework', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Http', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MQ', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Cache', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=219,
  serialized_end=304,
)
_sym_db.RegisterEnumDescriptor(_SPANLAYER)

SpanLayer = enum_type_wrapper.EnumTypeWrapper(_SPANLAYER)
Entry = 0
Exit = 1
Local = 2
CrossProcess = 0
CrossThread = 1
Unknown = 0
Database = 1
RPCFramework = 2
Http = 3
MQ = 4
Cache = 5



_UPSTREAMSEGMENT = _descriptor.Descriptor(
  name='UpstreamSegment',
  full_name='UpstreamSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='globalTraceIds', full_name='UpstreamSegment.globalTraceIds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segment', full_name='UpstreamSegment.segment', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=98,
)


_UNIQUEID = _descriptor.Descriptor(
  name='UniqueId',
  full_name='UniqueId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='idParts', full_name='UniqueId.idParts', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=127,
)

_UPSTREAMSEGMENT.fields_by_name['globalTraceIds'].message_type = _UNIQUEID
DESCRIPTOR.message_types_by_name['UpstreamSegment'] = _UPSTREAMSEGMENT
DESCRIPTOR.message_types_by_name['UniqueId'] = _UNIQUEID
DESCRIPTOR.enum_types_by_name['SpanType'] = _SPANTYPE
DESCRIPTOR.enum_types_by_name['RefType'] = _REFTYPE
DESCRIPTOR.enum_types_by_name['SpanLayer'] = _SPANLAYER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpstreamSegment = _reflection.GeneratedProtocolMessageType('UpstreamSegment', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMSEGMENT,
  '__module__' : 'common.trace_common_pb2'
  # @@protoc_insertion_point(class_scope:UpstreamSegment)
  })
_sym_db.RegisterMessage(UpstreamSegment)

UniqueId = _reflection.GeneratedProtocolMessageType('UniqueId', (_message.Message,), {
  'DESCRIPTOR' : _UNIQUEID,
  '__module__' : 'common.trace_common_pb2'
  # @@protoc_insertion_point(class_scope:UniqueId)
  })
_sym_db.RegisterMessage(UniqueId)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
