# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common/common.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n(org.apache.skywalking.apm.network.commonP\001\252\002\032SkyWalking.NetworkProtocol',
  serialized_pb=b'\n\x13\x63ommon/common.proto\"0\n\x12KeyStringValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"-\n\x0fKeyIntValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"\x1b\n\x03\x43PU\x12\x14\n\x0cusagePercent\x18\x02 \x01(\x01\"&\n\x08\x43ommands\x12\x1a\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x08.Command\"=\n\x07\x43ommand\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12!\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x13.KeyStringValuePair*0\n\x0b\x44\x65tectPoint\x12\n\n\x06\x63lient\x10\x00\x12\n\n\x06server\x10\x01\x12\t\n\x05proxy\x10\x02\x42I\n(org.apache.skywalking.apm.network.commonP\x01\xaa\x02\x1aSkyWalking.NetworkProtocolb\x06proto3'
)

_DETECTPOINT = _descriptor.EnumDescriptor(
  name='DetectPoint',
  full_name='DetectPoint',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='client', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='server', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='proxy', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=252,
  serialized_end=300,
)
_sym_db.RegisterEnumDescriptor(_DETECTPOINT)

DetectPoint = enum_type_wrapper.EnumTypeWrapper(_DETECTPOINT)
client = 0
server = 1
proxy = 2



_KEYSTRINGVALUEPAIR = _descriptor.Descriptor(
  name='KeyStringValuePair',
  full_name='KeyStringValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='KeyStringValuePair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='KeyStringValuePair.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23,
  serialized_end=71,
)


_KEYINTVALUEPAIR = _descriptor.Descriptor(
  name='KeyIntValuePair',
  full_name='KeyIntValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='KeyIntValuePair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='KeyIntValuePair.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=118,
)


_CPU = _descriptor.Descriptor(
  name='CPU',
  full_name='CPU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='usagePercent', full_name='CPU.usagePercent', index=0,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=147,
)


_COMMANDS = _descriptor.Descriptor(
  name='Commands',
  full_name='Commands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='Commands.commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=187,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='Command.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='Command.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=250,
)

_COMMANDS.fields_by_name['commands'].message_type = _COMMAND
_COMMAND.fields_by_name['args'].message_type = _KEYSTRINGVALUEPAIR
DESCRIPTOR.message_types_by_name['KeyStringValuePair'] = _KEYSTRINGVALUEPAIR
DESCRIPTOR.message_types_by_name['KeyIntValuePair'] = _KEYINTVALUEPAIR
DESCRIPTOR.message_types_by_name['CPU'] = _CPU
DESCRIPTOR.message_types_by_name['Commands'] = _COMMANDS
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.enum_types_by_name['DetectPoint'] = _DETECTPOINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyStringValuePair = _reflection.GeneratedProtocolMessageType('KeyStringValuePair', (_message.Message,), {
  'DESCRIPTOR' : _KEYSTRINGVALUEPAIR,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:KeyStringValuePair)
  })
_sym_db.RegisterMessage(KeyStringValuePair)

KeyIntValuePair = _reflection.GeneratedProtocolMessageType('KeyIntValuePair', (_message.Message,), {
  'DESCRIPTOR' : _KEYINTVALUEPAIR,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:KeyIntValuePair)
  })
_sym_db.RegisterMessage(KeyIntValuePair)

CPU = _reflection.GeneratedProtocolMessageType('CPU', (_message.Message,), {
  'DESCRIPTOR' : _CPU,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:CPU)
  })
_sym_db.RegisterMessage(CPU)

Commands = _reflection.GeneratedProtocolMessageType('Commands', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDS,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:Commands)
  })
_sym_db.RegisterMessage(Commands)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
  'DESCRIPTOR' : _COMMAND,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:Command)
  })
_sym_db.RegisterMessage(Command)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
