# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: language_agent_v2/trace.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from python2sky.proto.common import common_pb2 as common_dot_common__pb2
from python2sky.proto.common import trace_common_pb2 as common_dot_trace__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='language_agent_v2/trace.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n3org.apache.skywalking.apm.network.language.agent.v2P\001\252\002\032SkyWalking.NetworkProtocol',
  serialized_pb=b'\n\x1dlanguage_agent_v2/trace.proto\x1a\x13\x63ommon/common.proto\x1a\x19\x63ommon/trace-common.proto\"\x95\x01\n\rSegmentObject\x12!\n\x0etraceSegmentId\x18\x01 \x01(\x0b\x32\t.UniqueId\x12\x1c\n\x05spans\x18\x02 \x03(\x0b\x32\r.SpanObjectV2\x12\x11\n\tserviceId\x18\x03 \x01(\x05\x12\x19\n\x11serviceInstanceId\x18\x04 \x01(\x05\x12\x15\n\risSizeLimited\x18\x05 \x01(\x08\"\xc1\x02\n\x10SegmentReference\x12\x19\n\x07refType\x18\x01 \x01(\x0e\x32\x08.RefType\x12\'\n\x14parentTraceSegmentId\x18\x02 \x01(\x0b\x32\t.UniqueId\x12\x14\n\x0cparentSpanId\x18\x03 \x01(\x05\x12\x1f\n\x17parentServiceInstanceId\x18\x04 \x01(\x05\x12\x16\n\x0enetworkAddress\x18\x05 \x01(\t\x12\x18\n\x10networkAddressId\x18\x06 \x01(\x05\x12\x1e\n\x16\x65ntryServiceInstanceId\x18\x07 \x01(\x05\x12\x15\n\rentryEndpoint\x18\x08 \x01(\t\x12\x17\n\x0f\x65ntryEndpointId\x18\t \x01(\x05\x12\x16\n\x0eparentEndpoint\x18\n \x01(\t\x12\x18\n\x10parentEndpointId\x18\x0b \x01(\x05\"\xf3\x02\n\x0cSpanObjectV2\x12\x0e\n\x06spanId\x18\x01 \x01(\x05\x12\x14\n\x0cparentSpanId\x18\x02 \x01(\x05\x12\x11\n\tstartTime\x18\x03 \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\x04 \x01(\x03\x12\x1f\n\x04refs\x18\x05 \x03(\x0b\x32\x11.SegmentReference\x12\x17\n\x0foperationNameId\x18\x06 \x01(\x05\x12\x15\n\roperationName\x18\x07 \x01(\t\x12\x0e\n\x06peerId\x18\x08 \x01(\x05\x12\x0c\n\x04peer\x18\t \x01(\t\x12\x1b\n\x08spanType\x18\n \x01(\x0e\x32\t.SpanType\x12\x1d\n\tspanLayer\x18\x0b \x01(\x0e\x32\n.SpanLayer\x12\x13\n\x0b\x63omponentId\x18\x0c \x01(\x05\x12\x11\n\tcomponent\x18\r \x01(\t\x12\x0f\n\x07isError\x18\x0e \x01(\x08\x12!\n\x04tags\x18\x0f \x03(\x0b\x32\x13.KeyStringValuePair\x12\x12\n\x04logs\x18\x10 \x03(\x0b\x32\x04.Log\"6\n\x03Log\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12!\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x13.KeyStringValuePair2G\n\x19TraceSegmentReportService\x12*\n\x07\x63ollect\x12\x10.UpstreamSegment\x1a\t.Commands\"\x00(\x01\x42T\n3org.apache.skywalking.apm.network.language.agent.v2P\x01\xaa\x02\x1aSkyWalking.NetworkProtocolb\x06proto3'
  ,
  dependencies=[common_dot_common__pb2.DESCRIPTOR,common_dot_trace__common__pb2.DESCRIPTOR,])




_SEGMENTOBJECT = _descriptor.Descriptor(
  name='SegmentObject',
  full_name='SegmentObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='traceSegmentId', full_name='SegmentObject.traceSegmentId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spans', full_name='SegmentObject.spans', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceId', full_name='SegmentObject.serviceId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceInstanceId', full_name='SegmentObject.serviceInstanceId', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSizeLimited', full_name='SegmentObject.isSizeLimited', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=231,
)


_SEGMENTREFERENCE = _descriptor.Descriptor(
  name='SegmentReference',
  full_name='SegmentReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='refType', full_name='SegmentReference.refType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentTraceSegmentId', full_name='SegmentReference.parentTraceSegmentId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentSpanId', full_name='SegmentReference.parentSpanId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentServiceInstanceId', full_name='SegmentReference.parentServiceInstanceId', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkAddress', full_name='SegmentReference.networkAddress', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkAddressId', full_name='SegmentReference.networkAddressId', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entryServiceInstanceId', full_name='SegmentReference.entryServiceInstanceId', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entryEndpoint', full_name='SegmentReference.entryEndpoint', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entryEndpointId', full_name='SegmentReference.entryEndpointId', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentEndpoint', full_name='SegmentReference.parentEndpoint', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentEndpointId', full_name='SegmentReference.parentEndpointId', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=555,
)


_SPANOBJECTV2 = _descriptor.Descriptor(
  name='SpanObjectV2',
  full_name='SpanObjectV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spanId', full_name='SpanObjectV2.spanId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentSpanId', full_name='SpanObjectV2.parentSpanId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='SpanObjectV2.startTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='SpanObjectV2.endTime', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refs', full_name='SpanObjectV2.refs', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operationNameId', full_name='SpanObjectV2.operationNameId', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operationName', full_name='SpanObjectV2.operationName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peerId', full_name='SpanObjectV2.peerId', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer', full_name='SpanObjectV2.peer', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spanType', full_name='SpanObjectV2.spanType', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spanLayer', full_name='SpanObjectV2.spanLayer', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='componentId', full_name='SpanObjectV2.componentId', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component', full_name='SpanObjectV2.component', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isError', full_name='SpanObjectV2.isError', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='SpanObjectV2.tags', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logs', full_name='SpanObjectV2.logs', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=929,
)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='Log.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='Log.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=985,
)

_SEGMENTOBJECT.fields_by_name['traceSegmentId'].message_type = common_dot_trace__common__pb2._UNIQUEID
_SEGMENTOBJECT.fields_by_name['spans'].message_type = _SPANOBJECTV2
_SEGMENTREFERENCE.fields_by_name['refType'].enum_type = common_dot_trace__common__pb2._REFTYPE
_SEGMENTREFERENCE.fields_by_name['parentTraceSegmentId'].message_type = common_dot_trace__common__pb2._UNIQUEID
_SPANOBJECTV2.fields_by_name['refs'].message_type = _SEGMENTREFERENCE
_SPANOBJECTV2.fields_by_name['spanType'].enum_type = common_dot_trace__common__pb2._SPANTYPE
_SPANOBJECTV2.fields_by_name['spanLayer'].enum_type = common_dot_trace__common__pb2._SPANLAYER
_SPANOBJECTV2.fields_by_name['tags'].message_type = common_dot_common__pb2._KEYSTRINGVALUEPAIR
_SPANOBJECTV2.fields_by_name['logs'].message_type = _LOG
_LOG.fields_by_name['data'].message_type = common_dot_common__pb2._KEYSTRINGVALUEPAIR
DESCRIPTOR.message_types_by_name['SegmentObject'] = _SEGMENTOBJECT
DESCRIPTOR.message_types_by_name['SegmentReference'] = _SEGMENTREFERENCE
DESCRIPTOR.message_types_by_name['SpanObjectV2'] = _SPANOBJECTV2
DESCRIPTOR.message_types_by_name['Log'] = _LOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SegmentObject = _reflection.GeneratedProtocolMessageType('SegmentObject', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTOBJECT,
  '__module__' : 'language_agent_v2.trace_pb2'
  # @@protoc_insertion_point(class_scope:SegmentObject)
  })
_sym_db.RegisterMessage(SegmentObject)

SegmentReference = _reflection.GeneratedProtocolMessageType('SegmentReference', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTREFERENCE,
  '__module__' : 'language_agent_v2.trace_pb2'
  # @@protoc_insertion_point(class_scope:SegmentReference)
  })
_sym_db.RegisterMessage(SegmentReference)

SpanObjectV2 = _reflection.GeneratedProtocolMessageType('SpanObjectV2', (_message.Message,), {
  'DESCRIPTOR' : _SPANOBJECTV2,
  '__module__' : 'language_agent_v2.trace_pb2'
  # @@protoc_insertion_point(class_scope:SpanObjectV2)
  })
_sym_db.RegisterMessage(SpanObjectV2)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
  'DESCRIPTOR' : _LOG,
  '__module__' : 'language_agent_v2.trace_pb2'
  # @@protoc_insertion_point(class_scope:Log)
  })
_sym_db.RegisterMessage(Log)


DESCRIPTOR._options = None

_TRACESEGMENTREPORTSERVICE = _descriptor.ServiceDescriptor(
  name='TraceSegmentReportService',
  full_name='TraceSegmentReportService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=987,
  serialized_end=1058,
  methods=[
  _descriptor.MethodDescriptor(
    name='collect',
    full_name='TraceSegmentReportService.collect',
    index=0,
    containing_service=None,
    input_type=common_dot_trace__common__pb2._UPSTREAMSEGMENT,
    output_type=common_dot_common__pb2._COMMANDS,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRACESEGMENTREPORTSERVICE)

DESCRIPTOR.services_by_name['TraceSegmentReportService'] = _TRACESEGMENTREPORTSERVICE

# @@protoc_insertion_point(module_scope)
